from __future__ import unicode_literals

from autocomplete_light import shortcuts as al
from django.db.models import Q
from django.utils.translation import ugettext_lazy as _

from jmb.fax import models
from jmb.organization.models import Contact, Organization

class FaxContact(object):

    """Stupid Simple object that share get_fax_description with Contacts and Organization
    """

    def __init__(self, descr):
        self.descr = descr

    def get_fax_description(self):
        return self.descr

class RecipientAutocomplete(al.AutocompleteBase):

    """
    Autocompletion to be used by al, that
    """
    choices = Contact.objects.all
    attrs = {
        'placeholder': _('type number or part of the name'),
    }

    def choices_for_request(self):
        q = self.request.GET.get('q', '')
        ## per introdurre un numero che non esiste in rubrica aggiungere: ';'
        ## FIXME: ',' non funziona...
        if ';' in q or ',' in q:
            yield FaxContact(q.replace(';', '').replace(',', ''))
        else:
            for contact in self.contact_choices(q):
                yield(contact)
            for organization in self.organization_choices(q):
                yield(organization)

    def contact_choices(self, q):
        search_fields = ('organization__name', 'last_name', 'first_name', 'fax')
        choices = Contact.objects.exclude(Q(fax__isnull=True) | Q(fax=''))
        conditions = Q()
        for search_field in search_fields:
            conditions |= Q(**{construct_search(search_field): q})

        return choices.filter(conditions)

    def organization_choices(self, q):
        search_fields = ('name', 'fax')
        choices = Organization.objects.exclude(Q(fax__isnull=True) | Q(fax=''))
        conditions = Q()
        for search_field in search_fields:
            conditions |= Q(**{construct_search(search_field): q})

        return choices.filter(conditions)

    def choices_for_values(self):
        return [FaxContact(val) for val in self.values if val]

    def choice_label(self, choice):
        return choice.get_fax_description()

    def choice_value(self, choice):
        return choice.get_fax_description()

def construct_search(field_name):
    if field_name.startswith('^'):
        return "%s__istartswith" % field_name[1:]
    elif field_name.startswith('@'):
        return "%s__search" % field_name[1:]
    else:
        return "%s__icontains" % field_name

al.register(RecipientAutocomplete, name='RecipientAutocomplete')
