# coding: utf-8
"""
.. _retrieve-kpn-fax:

hyla_notify
=============

Command to notify to the webapplication that a fax has been received/ has been sent 
by hylafax


utilizzo::

  dj hyla_notify --in doneq/q11
  dj hyla_notify --out C000001743

as explained in the :ref:`hylafax utils <hylafax>`

:-d: variabile Booleana per cancellare il messaggi una volta recuperati
:-l: variabile Numero per limitare il numero di messaggi recuperare
:-v: variabile Booleana per visualizzare i print
:-b, --backup: backup messages in 
"""


from __future__ import unicode_literals

import re
import os
import sys
import email
import tempfile
import datetime
import logging

from django.core.mail.message import EmailMessage
from django.core.management.base import BaseCommand
from django.conf import settings
from django.core import mail
from django.utils import translation

from optparse import make_option
from jmb.fax import hylafax

logger = logging.getLogger('jmb.fax')

class Command(BaseCommand):

    """
    """
    help = "Wao!"

    option_list = BaseCommand.option_list + (
        make_option('-l', '--lang', dest='lang', help='Language for translations',
                    default='it'),
        make_option('-x', '--exit-code', dest='exit_code', help='Exit code from hylafax - OUT',
                    default=None),
        make_option('-o', '--out', dest='queue', help='Queue id from hylafax - OUT',
                    default=None),
        make_option('-i', '--in', dest='commid', help='COMMID from hylafax - IN',
                    default=None),
    )

    def handle(self, *args, **options):
        queue = options.get('queue')
        commid = options.get('commid')
        translation.activate(options.get('lang'))

        if queue:
            fax_out = hylafax.FaxOut(queue, options.get('exit_code'))
            fax_out.save_and_notify()
        elif commid:
            fax_in = hylafax.FaxIn(commid)
            fax_in.save_and_notify()
