# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
from django.conf import settings
import ckeditor.fields


class Migration(migrations.Migration):

    dependencies = [
        ('auth', '0006_require_contenttypes_0002'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Device',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.IntegerField(default=1, null=True, verbose_name='Status', choices=[(0, 'Inactive'), (1, 'Active')])),
                ('name', models.CharField(unique=True, max_length=100, verbose_name='Name')),
                ('description', models.CharField(max_length=200, null=True, verbose_name='Description', blank=True)),
                ('type', models.CharField(max_length=12, choices=[('hyla', 'Hylafax'), ('kpn', 'Kpn Messagenet'), ('codema', 'Codema')])),
                ('from_user', models.CharField(help_text='The email authorized to send by Codema', max_length=50, null=True, blank=True)),
                ('kpn_password', models.CharField(max_length=50, null=True, blank=True)),
                ('kpn_url', models.CharField(help_text='URL used to get asyncronous notification from KPN service (MUST: port 80, 8080, or 50000+)', max_length=80, null=True, blank=True)),
                ('pop_host', models.CharField(help_text='IP or hostname of host to poll via POP3', max_length=50, null=True, blank=True)),
                ('pop_user', models.CharField(max_length=50, null=True, blank=True)),
                ('pop_use_ssl', models.BooleanField(default=False)),
                ('pop_password', models.CharField(max_length=50, null=True, blank=True)),
                ('smtp_host', models.CharField(help_text='IP or hostname of host to use as SMTP relay', max_length=50, null=True, blank=True)),
                ('smtp_user', models.CharField(max_length=50, null=True, blank=True)),
                ('smtp_password', models.CharField(max_length=50, null=True, blank=True)),
                ('smtp_port', models.IntegerField(default=25, null=True, blank=True)),
                ('smtp_use_ssl', models.BooleanField(default=False)),
                ('creator', models.ForeignKey(related_name='fax_device_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='fax_device_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Document',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('ordering', models.IntegerField(default=0, verbose_name='ordering')),
                ('file', models.FileField(upload_to='fax/', verbose_name='file')),
                ('creator', models.ForeignKey(related_name='fax_document_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'ordering': ('ordering', 'date_create'),
                'verbose_name': 'Document',
                'verbose_name_plural': 'Documents',
            },
        ),
        migrations.CreateModel(
            name='Fax',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.IntegerField(default='3', verbose_name='status', choices=[(2, 'Received'), (3, 'Queued'), (4, 'Sent'), (5, 'Failed'), (6, 'Multi Queued'), (7, 'Multi Sent'), (8, 'To Send'), (9, 'Accepted by peer')])),
                ('job', models.CharField(help_text='job reference', max_length=15, null=True, verbose_name='job', blank=True)),
                ('keywords', models.CharField(max_length=100, null=True, verbose_name='keywords', blank=True)),
                ('pages', models.PositiveSmallIntegerField(null=True, verbose_name='pages', blank=True)),
                ('date_required', models.DateTimeField(help_text='date within fax must be sent - Not implemented', null=True, verbose_name='date required', blank=True)),
                ('date_sent', models.DateTimeField(null=True, verbose_name='date sent', blank=True)),
                ('recipient', models.CharField(max_length=100, null=True, verbose_name='recipient', blank=True)),
                ('recipient_number', models.CharField(help_text='To use a number not in the addreessbook, type ";" after the number', max_length=16, verbose_name='recipient number')),
                ('sender', models.CharField(max_length=100, null=True, verbose_name='sender', blank=True)),
                ('sender_number', models.CharField(max_length=16, null=True, verbose_name='sender number', blank=True)),
                ('duration', models.CharField(max_length=10, null=True, verbose_name='duration', blank=True)),
                ('error', models.CharField(max_length=150, null=True, verbose_name='error', blank=True)),
                ('subject', models.CharField(max_length=300, verbose_name='subject')),
                ('read', models.IntegerField(default=0, null=True, verbose_name='read', blank=True, choices=[(0, 'Not Read'), (1, 'Read')])),
                ('priority', models.PositiveSmallIntegerField(default=127, null=True, verbose_name='priority', blank=True, choices=[(127, 'Low'), (120, 'Normal'), (100, 'High'), (50, 'Urgent')])),
                ('sent_by', models.CharField(default='W', max_length=1, verbose_name='Sent By', choices=[('W', 'WEB'), ('M', 'MAIL')])),
                ('status_message', models.CharField(max_length=200, null=True, verbose_name='Status message', blank=True)),
                ('is_public', models.BooleanField(default=False)),
            ],
            options={
                'ordering': ('-date_sent',),
                'verbose_name': 'Fax',
                'verbose_name_plural': 'Fax',
                'permissions': (('view_fax', 'Can view fax'), ('download_all_report', 'Can view all reports'), ('download_all_document', 'Can download all documents'), ('send_all_fax', 'Can send all faxes'), ('list_all_fax', 'Can list all faxes'), ('list_all_fax_not_assigned', 'Can list all faxes not assigned'), ('delete_all_fax_to_send', 'Can Delete ALL FAX TO SEND'), ('delete_all_own_fax_to_send', 'Can Delete ALL OWN FAX TO SEND'), ('delete_all_owngroup_fax_to_send', 'Can Delete ALL OWN GROUP FAX TO SEND'), ('delete_all_own_fax', 'Can Delete ALL OWN FAX'), ('delete_all_owngroup_fax', 'Can Delete ALL OWN GROUP FAX')),
            },
        ),
        migrations.CreateModel(
            name='FaxNumber',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.IntegerField(default=1, null=True, verbose_name='Status', choices=[(0, 'Inactive'), (1, 'Active')])),
                ('ordering', models.IntegerField(default=0, verbose_name='ordering')),
                ('number', models.CharField(unique=True, max_length=30, verbose_name='Number', db_column='dnumber')),
                ('name', models.CharField(max_length=100, null=True, verbose_name='Name', blank=True)),
                ('notify_mails', models.CharField(max_length=200, null=True, verbose_name='Notify Mails', blank=True)),
                ('send_at_received_fax', models.BooleanField(default=True)),
                ('send_at_sent_fax', models.BooleanField(default=True)),
                ('creator', models.ForeignKey(related_name='fax_faxnumber_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('device', models.ManyToManyField(related_name='numbers', verbose_name='Device', to='fax.Device')),
                ('last_modifier', models.ForeignKey(related_name='fax_faxnumber_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'ordering': ['ordering'],
                'verbose_name': 'Fax Number',
                'verbose_name_plural': 'Fax Numbers',
            },
        ),
        migrations.CreateModel(
            name='FaxPermission',
            fields=[
                ('permission_ptr', models.OneToOneField(parent_link=True, auto_created=True, primary_key=True, serialize=False, to='auth.Permission')),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('number', models.CharField(max_length=30, verbose_name='Number', db_column='dnumber')),
                ('creator', models.ForeignKey(related_name='fax_faxpermission_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='fax_faxpermission_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'abstract': False,
            },
            bases=('auth.permission', models.Model),
        ),
        migrations.CreateModel(
            name='Cover',
            fields=[
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('fax', models.OneToOneField(related_name='cover', primary_key=True, serialize=False, to='fax.Fax')),
                ('to_company', models.CharField(max_length=100, null=True, verbose_name='To', blank=True)),
                ('from_company', models.CharField(max_length=100, null=True, verbose_name='From', blank=True)),
                ('to_person', models.CharField(max_length=100, null=True, verbose_name='To Person', blank=True)),
                ('from_person', models.CharField(max_length=100, null=True, verbose_name='From Person', blank=True)),
                ('pages', models.CharField(help_text='Cover Include', max_length=2, null=True, verbose_name='Pag.', blank=True)),
                ('subject', models.CharField(max_length=100, null=True, verbose_name='Subject', blank=True)),
                ('notes', ckeditor.fields.RichTextField(null=True, verbose_name='Notes', blank=True)),
            ],
            options={
                'verbose_name': 'Cover',
                'verbose_name_plural': 'Cover',
            },
        ),
        migrations.AddField(
            model_name='fax',
            name='creator',
            field=models.ForeignKey(related_name='fax_fax_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True),
        ),
        migrations.AddField(
            model_name='fax',
            name='device',
            field=models.ForeignKey(verbose_name='Nr. Fax/line', to='fax.Device'),
        ),
        migrations.AddField(
            model_name='fax',
            name='last_modifier',
            field=models.ForeignKey(related_name='fax_fax_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True),
        ),
        migrations.AddField(
            model_name='fax',
            name='notify_group',
            field=models.ForeignKey(verbose_name='notify group', blank=True, to='auth.Group', null=True),
        ),
        migrations.AddField(
            model_name='fax',
            name='submitter',
            field=models.ForeignKey(verbose_name='submitter', blank=True, to=settings.AUTH_USER_MODEL, null=True),
        ),
        migrations.AddField(
            model_name='document',
            name='fax',
            field=models.ForeignKey(related_name='documents', to='fax.Fax'),
        ),
        migrations.AddField(
            model_name='document',
            name='last_modifier',
            field=models.ForeignKey(related_name='fax_document_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True),
        ),
    ]
